DataLad extension for functionality that was phased out of the core package
***************************************************************************

API
===

High-level API commands
-----------------------

.. currentmodule:: datalad.api
.. autosummary::
   :toctree: generated

   ls
   publish
   metadata
   search
   extract_metadata
   aggregate_metadata


Command line reference
----------------------

.. toctree::
   :maxdepth: 1

   generated/man/datalad-ls
   generated/man/datalad-publish
   generated/man/datalad-metadata
   generated/man/datalad-extract-metadata
   generated/man/datalad-aggregate-metadata
   generated/man/datalad-search


Miscellaneous functionality
---------------------------

.. currentmodule:: datalad_deprecated
.. autosummary::
   :toctree: generated

   auto.AutomagicIO


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
